@@ -69,7 +69,8 @@ class NanotubeGenerator(Nanotube, StructureGenerator):
         Number of repeat unit cells in the :math:`z` direction, along
         the *length* of the nanotube.
     element1, element2 : {str, int}, optional
-        Element symbol or atomic number of basis atoms 1 and 2
+        Element symbol or atomic number of basis
+        :py:class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -302,7 +303,8 @@ class NanotubeBundleGenerator(NanotubeGenerator, NanotubeBundle):
     nx, ny, nz : int, optional
         Number of repeat unit cells in the :math:`x, y, z` dimensions.
     element1, element2 : {str, int}, optional
-        Element symbol or atomic number of basis atoms 1 and 2
+        Element symbol or atomic number of basis
+        :py:class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
@@ -598,7 +600,8 @@ class MWNTGenerator(NanotubeGenerator, NanotubeBundle):
     nx, ny, nz : int, optional
         Number of repeat unit cells in the :math:`x, y, z` dimensions.
     element1, element2 : {str, int}, optional
-        Element symbol or atomic number of basis atoms 1 and 2
+        Element symbol or atomic number of basis
+        :py:class:`~sknano.chemistry.Atoms` 1 and 2
     bond : float, optional
         :math:`\\mathrm{a}_{\\mathrm{CC}} =` distance between
         nearest neighbor atoms. Must be in units of **Angstroms**.
