@@ -17,7 +17,7 @@ from pkshared.tools.fiofuncs import get_fpath
 
 from ..chemistry import Atom, Atoms
 from ._structure_data import StructureReader, StructureWriter, \
-    StructureDataError
+    StructureDataError, default_comment_line
 
 
 __all__ = ['DATAReader', 'DATAWriter', 'LAMMPSDATA',
@@ -25,7 +25,7 @@ __all__ = ['DATAReader', 'DATAWriter', 'LAMMPSDATA',
 
 
 class DATAReader(StructureReader):
-    """Class for reading ``LAMMPS data`` file format.
+    """Class for reading `LAMMPS data` file format.
 
     Parameters
     ----------
@@ -128,7 +128,7 @@ class DATAReader(StructureReader):
         self._parse_boxbounds()
 
     def _parse_atoms(self):
-        """Populate Atoms object with Atom objects"""
+        """Populate `Atoms` object with `Atom` objects"""
         atoms_section = self._sections['Atoms']
         atoms_section_syntax = self._section_syntax_dict['Atoms']
 
@@ -179,17 +179,17 @@ class DATAReader(StructureReader):
                 #    print('unknown atom keyword: {}'.format(kw))
 
             atom = Atom(**atom_kwargs)
-            self._atoms.append(atom)
+            self._structure_atoms.append(atom)
 
     def _parse_atomtypes(self):
-        Ntypes = self._atoms.Ntypes
-        atomtypes = self._atoms.atomtypes
+        Ntypes = self._structure_atoms.Ntypes
+        atomtypes = self._structure_atoms.atomtypes
         if Ntypes != self._headers['atom types']:
             for atomtype in xrange(1, self._headers['atom types'] + 1):
                 if atomtype not in atomtypes:
                     mass = self._sections['Masses'][atomtype - 1][
                         self._section_properties['Masses']['mass']['index']]
-                    self._atoms.add_atomtype(
+                    self._structure_atoms.add_atomtype(
                         Atom(atomtype=atomtype, mass=mass))
 
     def _parse_boxbounds(self):
@@ -199,7 +199,7 @@ class DATAReader(StructureReader):
             self._boxbounds[dim] = {'min': bounds[0], 'max': bounds[-1]}
 
     def get(self, section_key, colnum=None, colname=None, colindex=None):
-        """Return section with ``section key``.
+        """Return section with `section_key`.
 
         Parameters
         ----------
@@ -257,29 +257,33 @@ class DATAWriter(StructureWriter):
         Parameters
         ----------
         fname : str
-        atoms : `Atoms`
-            An :py:class:`Atoms` instance.
+        atoms : :py:class:`~sknano.chemistry.Atoms`
+            An :py:class:`~sknano.chemistry.Atoms` instance.
         boxbounds : dict, optional
-            If ``None``, determined automatically from atom coordinates.
+            If `None`, determined automatically from the `atoms` coordinates.
         comment_line : str, optional
-            A string written to the first line of ``data`` file. If ``None``,
-            then it is set to the full path of the output ``data`` file.
+            A string written to the first line of `data` file. If `None`,
+            then it is set to the full path of the output `data` file.
         assume_unique_atoms : bool, optional
-            Check that each Atom in Atoms has a unique atomID. If the check
-            fails, then assign a unique atomID to each Atom.
-            If ``assume_unique_atoms`` is True, but the atomID's are not
-            unique, LAMMPS will not be able to read the data file.
+            Check that each :py:class:`~sknano.chemistry.Atom` in `atoms`
+            has a unique :py:attr:`~sknano.chemistry.Atom.atomID`.
+            If the check fails, then assign a unique
+            :py:attr:`~sknano.chemistry.Atom.atomID` to each
+            :py:class:`~sknano.chemistry.Atom`.
+            If `assume_unique_atoms` is True, but the atomID's are not unique,
+            LAMMPS will not be able to read the data file.
         verbose : bool, optional
             verbose output
 
         """
         if not isinstance(atoms, Atoms):
-            raise TypeError('atoms argument must be an ``Atoms`` instance')
+            raise TypeError('atoms argument must be an `Atoms` instance')
         else:
             fname = get_fpath(fname=fname, ext='data', overwrite=True,
                               add_fnum=False)
             if comment_line is None:
-                comment_line = fname
+                #comment_line = fname
+                comment_line = default_comment_line
 
             atoms.rezero_coords()
 
@@ -452,7 +456,7 @@ class LAMMPSDATA(DATAReader):
             self._section_properties[section_key][atom_attr]['dtype']
         new_data = np.asarray(new_data, dtype=attr_dtype)
 
-        for i, atom in enumerate(self._atoms):
+        for i, atom in enumerate(self._structure_atoms):
             self._sections[section_key][i][colidx] = \
                 attr_dtype(float(new_data[i]))
             setattr(atom, atom_attr, attr_dtype(float(new_data[i])))
@@ -479,7 +483,7 @@ class LAMMPSDATA(DATAReader):
                     raise ValueError(error_msg)
             else:
                 datafile = self._fname
-            DATAWriter.write(fname=datafile, atoms=self._atoms,
+            DATAWriter.write(fname=datafile, atoms=self._structure_atoms,
                              boxbounds=self._boxbounds,
                              comment_line=self._comment_line)
         except (TypeError, ValueError) as e:
