@@ -166,17 +166,17 @@ class DUMPReader(StructureReader):
                     print('unknown atom keyword: {}'.format(kw))
 
             atom = Atom(**atom_kwargs)
-            self._atoms.append(atom)
+            self._structure_atoms.append(atom)
 
     def _parse_atomtypes(self):
-        Ntypes = self._atoms.Ntypes
-        atomtypes = self._atoms.atomtypes
+        Ntypes = self._structure_atoms.Ntypes
+        atomtypes = self._structure_atoms.atomtypes
         if Ntypes != self._headers['atom types']:
             for atomtype in xrange(1, self._headers['atom types'] + 1):
                 if atomtype not in atomtypes:
                     mass = self._sections['Masses'][atomtype - 1][
                         self._section_properties['Masses']['mass']['index']]
-                    self._atoms.add_atomtype(
+                    self._structure_atoms.add_atomtype(
                         Atom(atomtype=atomtype, mass=mass))
 
     def _parse_boxbounds(self):
@@ -509,7 +509,7 @@ class LAMMPSDUMP(DUMPReader):
             self._section_properties[section_key][atom_attr]['dtype']
         new_data = np.asarray(new_data, dtype=attr_dtype)
 
-        for i, atom in enumerate(self._atoms):
+        for i, atom in enumerate(self._structure_atoms):
             self._sections[section_key][i][colidx] = attr_dtype(new_data[i])
             setattr(atom, atom_attr, attr_dtype(new_data[i]))
 
@@ -532,7 +532,7 @@ class LAMMPSDUMP(DUMPReader):
                     raise ValueError(error_msg)
             else:
                 dumpfile = self._fname
-            DUMPWriter.write(fname=dumpfile, atoms=self._atoms,
+            DUMPWriter.write(fname=dumpfile, atoms=self._structure_atoms,
                              boxbounds=self._boxbounds,
                              comment_line=self._comment_line)
         except (TypeError, ValueError) as e:
